This is a better name for this function, so update it.

Tidy up the function comment to mention VPL. Use SPL_BUILD in the SPL
check, for clarity.

Signed-off-by: Simon Glass <s...@chromium.org>
---

(no changes since v1)

 arch/arm/mach-omap2/am33xx/board.c |  2 +-
 common/bloblist.c                  |  4 ++--
 common/spl/spl.c                   |  4 ++--
 include/spl.h                      | 16 +++++++++-------
 4 files changed, 14 insertions(+), 12 deletions(-)

diff --git a/arch/arm/mach-omap2/am33xx/board.c 
b/arch/arm/mach-omap2/am33xx/board.c
index e720fb6b21f..4e9ad8935e3 100644
--- a/arch/arm/mach-omap2/am33xx/board.c
+++ b/arch/arm/mach-omap2/am33xx/board.c
@@ -526,7 +526,7 @@ EVENT_SPY_SIMPLE(EVT_DM_POST_INIT_F, am33xx_dm_post_init);
 #ifdef CONFIG_DEBUG_UART_BOARD_INIT
 void board_debug_uart_init(void)
 {
-       if (u_boot_first_phase()) {
+       if (xpl_is_first_phase()) {
                hw_data_init();
                set_uart_mux_conf();
                setup_early_clocks();
diff --git a/common/bloblist.c b/common/bloblist.c
index 2008ab4d25c..fb86789df42 100644
--- a/common/bloblist.c
+++ b/common/bloblist.c
@@ -504,13 +504,13 @@ int bloblist_init(void)
         * If U-Boot is not in the first phase, an existing bloblist must be
         * at a fixed address.
         */
-       bool from_addr = fixed && !u_boot_first_phase();
+       bool from_addr = fixed && !xpl_is_first_phase();
        /*
         * If U-Boot is in the first phase that an arch custom routine should
         * install the bloblist passed from previous loader to this fixed
         * address.
         */
-       bool from_boot_arg = fixed && u_boot_first_phase();
+       bool from_boot_arg = fixed && xpl_is_first_phase();
 
        if (spl_prev_phase() == PHASE_TPL && !IS_ENABLED(CONFIG_TPL_BLOBLIST))
                from_addr = false;
diff --git a/common/spl/spl.c b/common/spl/spl.c
index dc73d3aff00..674ab35ede0 100644
--- a/common/spl/spl.c
+++ b/common/spl/spl.c
@@ -464,13 +464,13 @@ static int spl_common_init(bool setup_malloc)
                gd->malloc_ptr = 0;
        }
 #endif
-       ret = bootstage_init(u_boot_first_phase());
+       ret = bootstage_init(xpl_is_first_phase());
        if (ret) {
                debug("%s: Failed to set up bootstage: ret=%d\n", __func__,
                      ret);
                return ret;
        }
-       if (!u_boot_first_phase()) {
+       if (!xpl_is_first_phase()) {
                ret = bootstage_unstash_default();
                if (ret)
                        log_debug("Failed to unstash bootstage: ret=%d\n", ret);
diff --git a/include/spl.h b/include/spl.h
index fec5677c7a9..01057ee103e 100644
--- a/include/spl.h
+++ b/include/spl.h
@@ -34,24 +34,26 @@ struct spl_boot_device;
 enum boot_device;
 
 /*
  * u_boot_first_phase() - check if this is the first U-Boot phase
  *
- * U-Boot has up to three phases: TPL, SPL and U-Boot proper. Depending on the
- * build flags we can determine whether the current build is for the first
+ * U-Boot has up to four phases: TPL, VPL, SPL and U-Boot proper. Depending on
+ * the build flags we can determine whether the current build is for the first
  * phase of U-Boot or not. If there is no SPL, then this is U-Boot proper. If
  * there is SPL but no TPL, the the first phase is SPL. If there is TPL, then
- * it is the first phase.
+ * it is the first phase, etc.
  *
- * @returns true if this is the first phase of U-Boot
+ * Note that VPL can never be the first phase. If it exists, it is loaded from
+ * TPL
  *
+ * Return: true if this is the first phase of U-Boot
  */
-static inline bool u_boot_first_phase(void)
+static inline bool xpl_is_first_phase(void)
 {
        if (IS_ENABLED(CONFIG_TPL)) {
                if (IS_ENABLED(CONFIG_TPL_BUILD))
                        return true;
        } else if (IS_ENABLED(CONFIG_SPL)) {
-               if (IS_ENABLED(CONFIG_XPL_BUILD))
+               if (IS_ENABLED(CONFIG_SPL_BUILD))
                        return true;
        } else {
                return true;
@@ -34,24 +34,26 @@ struct spl_boot_device;
 
 /*
- * u_boot_first_phase() - check if this is the first U-Boot phase
+ * xpl_is_first_phase() - check if this is the first U-Boot phase
  *
-- 
2.34.1

Reply via email to